EXPORTS
	??0TBTDeviceList@@QAE@XZ @ 1 NONAME ; TBTDeviceList::TBTDeviceList(void)
	??0TBTDeviceResponseParams@@QAE@XZ @ 2 NONAME ; TBTDeviceResponseParams::TBTDeviceResponseParams(void)
	??0TBTDeviceSelectionParams@@QAE@XZ @ 3 NONAME ; TBTDeviceSelectionParams::TBTDeviceSelectionParams(void)
	??BTBTDeviceList@@QAEAAVTDes8@@XZ @ 4 NONAME ; TBTDeviceList::operator class TDes8 &(void)
	??BTBTDeviceList@@QAEABVTDesC8@@XZ @ 5 NONAME ; TBTDeviceList::operator class TDesC8 const &(void)
	?AddDevice@TBTDeviceList@@QAEHABVTBTDevAddr@@@Z @ 6 NONAME ; int TBTDeviceList::AddDevice(class TBTDevAddr const &)
	?BDAddr@TBTDeviceResponseParams@@QBEABVTBTDevAddr@@XZ @ 7 NONAME ; class TBTDevAddr const & TBTDeviceResponseParams::BDAddr(void) const
	?DeviceClass@TBTDeviceResponseParams@@QAE?AVTBTDeviceClass@@XZ @ 8 NONAME ; class TBTDeviceClass TBTDeviceResponseParams::DeviceClass(void)
	?DeviceClass@TBTDeviceSelectionParams@@QAE?AVTBTDeviceClass@@XZ @ 9 NONAME ; class TBTDeviceClass TBTDeviceSelectionParams::DeviceClass(void)
	?DeviceName@TBTDeviceResponseParams@@QBEABVTDesC16@@XZ @ 10 NONAME ; class TDesC16 const & TBTDeviceResponseParams::DeviceName(void) const
	?GetDevice@TBTDeviceList@@QAEHAAVTBTDevAddr@@@Z @ 11 NONAME ; int TBTDeviceList::GetDevice(class TBTDevAddr &)
	?IsValidBDAddr@TBTDeviceResponseParams@@QBEHXZ @ 12 NONAME ; int TBTDeviceResponseParams::IsValidBDAddr(void) const
	?IsValidDeviceClass@TBTDeviceResponseParams@@QAEHXZ @ 13 NONAME ; int TBTDeviceResponseParams::IsValidDeviceClass(void)
	?IsValidDeviceClass@TBTDeviceSelectionParams@@QAEHXZ @ 14 NONAME ; int TBTDeviceSelectionParams::IsValidDeviceClass(void)
	?IsValidDeviceName@TBTDeviceResponseParams@@QBEHXZ @ 15 NONAME ; int TBTDeviceResponseParams::IsValidDeviceName(void) const
	?IsValidUUID@TBTDeviceSelectionParams@@QAEHXZ @ 16 NONAME ; int TBTDeviceSelectionParams::IsValidUUID(void)
	?MaxNumberOfDevices@TBTDeviceList@@QAEIXZ @ 17 NONAME ; unsigned int TBTDeviceList::MaxNumberOfDevices(void)
	?Reset@TBTDeviceList@@QAEXXZ @ 18 NONAME ; void TBTDeviceList::Reset(void)
	?SetDeviceAddress@TBTDeviceResponseParams@@QAEXABVTBTDevAddr@@@Z @ 19 NONAME ; void TBTDeviceResponseParams::SetDeviceAddress(class TBTDevAddr const &)
	?SetDeviceClass@TBTDeviceResponseParams@@QAEXVTBTDeviceClass@@@Z @ 20 NONAME ; void TBTDeviceResponseParams::SetDeviceClass(class TBTDeviceClass)
	?SetDeviceClass@TBTDeviceSelectionParams@@QAEXVTBTDeviceClass@@@Z @ 21 NONAME ; void TBTDeviceSelectionParams::SetDeviceClass(class TBTDeviceClass)
	?SetDeviceName@TBTDeviceResponseParams@@QAEXABVTDesC16@@@Z @ 22 NONAME ; void TBTDeviceResponseParams::SetDeviceName(class TDesC16 const &)
	?SetUUID@TBTDeviceSelectionParams@@QAEXABVTUUID@@@Z @ 23 NONAME ; void TBTDeviceSelectionParams::SetUUID(class TUUID const &)
	?UUID@TBTDeviceSelectionParams@@QAEABVTUUID@@XZ @ 24 NONAME ; class TUUID const & TBTDeviceSelectionParams::UUID(void)
	??0TPbapAuthNotifierParams@@QAE@XZ @ 25 NONAME ; TPbapAuthNotifierParams::TPbapAuthNotifierParams(void)
	??0TPbapAuthNotifierResponse@@QAE@XZ @ 26 NONAME ; TPbapAuthNotifierResponse::TPbapAuthNotifierResponse(void)
	?IsValidPassword@TPbapAuthNotifierResponse@@QBEHXZ @ 27 NONAME ; int TPbapAuthNotifierResponse::IsValidPassword(void) const
	?IsValidRealm@TPbapAuthNotifierParams@@QBEHXZ @ 28 NONAME ; int TPbapAuthNotifierParams::IsValidRealm(void) const
	?IsValidRemoteAddr@TPbapAuthNotifierParams@@QBEHXZ @ 29 NONAME ; int TPbapAuthNotifierParams::IsValidRemoteAddr(void) const
	?Password@TPbapAuthNotifierResponse@@QBEABVTDesC16@@XZ @ 30 NONAME ; class TDesC16 const & TPbapAuthNotifierResponse::Password(void) const
	?Realm@TPbapAuthNotifierParams@@QBEABVTDesC16@@XZ @ 31 NONAME ; class TDesC16 const & TPbapAuthNotifierParams::Realm(void) const
	?RealmTruncated@TPbapAuthNotifierParams@@QBEHXZ @ 32 NONAME ; int TPbapAuthNotifierParams::RealmTruncated(void) const
	?RemoteAddr@TPbapAuthNotifierParams@@QBEABVTBTDevAddr@@XZ @ 33 NONAME ; class TBTDevAddr const & TPbapAuthNotifierParams::RemoteAddr(void) const
	?ResetPassword@TPbapAuthNotifierResponse@@QAEXXZ @ 34 NONAME ; void TPbapAuthNotifierResponse::ResetPassword(void)
	?SetPassword@TPbapAuthNotifierResponse@@QAEHABVTDesC16@@@Z @ 35 NONAME ; int TPbapAuthNotifierResponse::SetPassword(class TDesC16 const &)
	?SetRealm@TPbapAuthNotifierParams@@QAEXABVTDesC16@@@Z @ 36 NONAME ; void TPbapAuthNotifierParams::SetRealm(class TDesC16 const &)
	?SetRemoteAddr@TPbapAuthNotifierParams@@QAEXABVTBTDevAddr@@@Z @ 37 NONAME ; void TPbapAuthNotifierParams::SetRemoteAddr(class TBTDevAddr const &)
	?SetRequestedConnectionAddr@TPanConnectionList@@QAEXABVTBTDevAddr@@@Z @ 38 NONAME ; void TPanConnectionList::SetRequestedConnectionAddr(class TBTDevAddr const &)
	?UplinkAccessAllowed@TPanConnection@@QBEHXZ @ 39 NONAME ; int TPanConnection::UplinkAccessAllowed(void) const
	??0TPanConnection@@QAE@AAVTBTDevAddr@@H@Z @ 40 NONAME ; TPanConnection::TPanConnection(class TBTDevAddr &, int)
	??0TPanConnection@@QAE@XZ @ 41 NONAME ; TPanConnection::TPanConnection(void)
	??0TPanConnectionList@@QAE@XZ @ 42 NONAME ; TPanConnectionList::TPanConnectionList(void)
	?AddRemoteConnectionL@TPanConnectionList@@QAEXABVTPanConnection@@@Z @ 43 NONAME ; void TPanConnectionList::AddRemoteConnectionL(class TPanConnection const &)
	?CurrentLocalRole@TPanConnectionList@@QBEABVTUUID@@XZ @ 44 NONAME ; class TUUID const & TPanConnectionList::CurrentLocalRole(void) const
	?GetFirstRemoteConnection@TPanConnectionList@@QAEPBVTPanConnection@@XZ @ 45 NONAME ; class TPanConnection const * TPanConnectionList::GetFirstRemoteConnection(void)
	?GetNextRemoteConnection@TPanConnectionList@@QAEPBVTPanConnection@@XZ @ 46 NONAME ; class TPanConnection const * TPanConnectionList::GetNextRemoteConnection(void)
	?IsValid@TPanConnection@@QBEHXZ @ 47 NONAME ; int TPanConnection::IsValid(void) const
	?MaxNumberOfRemoteConnections@TPanConnectionList@@QAEEXZ @ 48 NONAME ; unsigned char TPanConnectionList::MaxNumberOfRemoteConnections(void)
	?RemoteDeviceAddress@TPanConnection@@QBEABVTBTDevAddr@@XZ @ 49 NONAME ; class TBTDevAddr const & TPanConnection::RemoteDeviceAddress(void) const
	?RequestedConnectionAddr@TPanConnectionList@@QAEPBVTBTDevAddr@@XZ @ 50 NONAME ; class TBTDevAddr const * TPanConnectionList::RequestedConnectionAddr(void)
	?SetCurrentLocalRole@TPanConnectionList@@QAEXABVTUUID@@@Z @ 51 NONAME ; void TPanConnectionList::SetCurrentLocalRole(class TUUID const &)
	??0TBTDeviceNameUpdateParams@@QAE@ABVTDesC16@@H@Z @ 52 NONAME ; TBTDeviceNameUpdateParams::TBTDeviceNameUpdateParams(class TDesC16 const &, int)
	??0TBTDeviceNameUpdateParams@@QAE@XZ @ 53 NONAME ; TBTDeviceNameUpdateParams::TBTDeviceNameUpdateParams(void)
	??0TBTNotifierUpdateParams2@@QAE@XZ @ 54 NONAME ; TBTNotifierUpdateParams2::TBTNotifierUpdateParams2(void)
	??0TBTNumericComparisonParams@@QAE@ABVTBTDevAddr@@ABVTDesC16@@KW4TComparisonScenario@0@H@Z @ 55 NONAME ; TBTNumericComparisonParams::TBTNumericComparisonParams(class TBTDevAddr const &, class TDesC16 const &, unsigned long, enum TBTNumericComparisonParams::TComparisonScenario, int)
	??0TBTNumericComparisonParams@@QAE@XZ @ 56 NONAME ; TBTNumericComparisonParams::TBTNumericComparisonParams(void)
	??0TBTPasskeyDisplayParams@@QAE@ABVTBTDevAddr@@ABVTDesC16@@KH@Z @ 57 NONAME ; TBTPasskeyDisplayParams::TBTPasskeyDisplayParams(class TBTDevAddr const &, class TDesC16 const &, unsigned long, int)
	??0TBTPasskeyDisplayParams@@QAE@XZ @ 58 NONAME ; TBTPasskeyDisplayParams::TBTPasskeyDisplayParams(void)
	??0TBTPasskeyDisplayUpdateParams@@QAE@W4THCIPasskeyEntryNotificationType@@@Z @ 59 NONAME ; TBTPasskeyDisplayUpdateParams::TBTPasskeyDisplayUpdateParams(enum THCIPasskeyEntryNotificationType)
	??0TBTPasskeyDisplayUpdateParams@@QAE@XZ @ 60 NONAME ; TBTPasskeyDisplayUpdateParams::TBTPasskeyDisplayUpdateParams(void)
	??0TBTPinCodeEntryNotifierParams@@QAE@ABVTBTDevAddr@@ABVTDesC16@@IHHI@Z @ 61 NONAME ; TBTPinCodeEntryNotifierParams::TBTPinCodeEntryNotifierParams(class TBTDevAddr const &, class TDesC16 const &, unsigned int, int, int, unsigned int)
	??0TBTPinCodeEntryNotifierParams@@QAE@XZ @ 62 NONAME ; TBTPinCodeEntryNotifierParams::TBTPinCodeEntryNotifierParams(void)
	?ComparisonScenario@TBTNumericComparisonParams@@QBE?AW4TComparisonScenario@1@XZ @ 63 NONAME ; enum TBTNumericComparisonParams::TComparisonScenario TBTNumericComparisonParams::ComparisonScenario(void) const
	?DeviceAddress@TBTNotifierParams2@@QBE?AVTBTDevAddr@@XZ @ 64 NONAME ; class TBTDevAddr TBTNotifierParams2::DeviceAddress(void) const
	?DeviceName@TBTDeviceNameUpdateParams@@QBE?AVTPtrC16@@XZ @ 65 NONAME ; class TPtrC16 TBTDeviceNameUpdateParams::DeviceName(void) const
	?DeviceName@TBTNotifierParams2@@QBE?AVTPtrC16@@XZ @ 66 NONAME ; class TPtrC16 TBTNotifierParams2::DeviceName(void) const
	?KeypressNotification@TBTPasskeyDisplayUpdateParams@@QBE?AW4THCIPasskeyEntryNotificationType@@XZ @ 67 NONAME ; enum THCIPasskeyEntryNotificationType TBTPasskeyDisplayUpdateParams::KeypressNotification(void) const
	?LocallyInitiated@TBTNumericComparisonParams@@QBEHXZ @ 68 NONAME ; int TBTNumericComparisonParams::LocallyInitiated(void) const
	?LocallyInitiated@TBTPasskeyDisplayParams@@QBEHXZ @ 69 NONAME ; int TBTPasskeyDisplayParams::LocallyInitiated(void) const
	?LocallyInitiated@TBTPinCodeEntryNotifierParams@@QBEHXZ @ 70 NONAME ; int TBTPinCodeEntryNotifierParams::LocallyInitiated(void) const
	?NumericalValue@TBTNumericComparisonParams@@QBEKXZ @ 71 NONAME ; unsigned long TBTNumericComparisonParams::NumericalValue(void) const
	?NumericalValue@TBTPasskeyDisplayParams@@QBEKXZ @ 72 NONAME ; unsigned long TBTPasskeyDisplayParams::NumericalValue(void) const
	?PinCodeMinLength@TBTPinCodeEntryNotifierParams@@QBEIXZ @ 73 NONAME ; unsigned int TBTPinCodeEntryNotifierParams::PinCodeMinLength(void) const
	?Result@TBTDeviceNameUpdateParams@@QBEHXZ @ 74 NONAME ; int TBTDeviceNameUpdateParams::Result(void) const
	?StrongPinCodeRequired@TBTPinCodeEntryNotifierParams@@QBEHXZ @ 75 NONAME ; int TBTPinCodeEntryNotifierParams::StrongPinCodeRequired(void) const
	?Type@TBTNotifierUpdateParams2@@QBE?AW4TUpdateParamType@1@XZ @ 76 NONAME ; enum TBTNotifierUpdateParams2::TUpdateParamType TBTNotifierUpdateParams2::Type(void) const
	?RecommendedPinCodeMinLength@TBTPinCodeEntryNotifierParams@@QBEIXZ @ 77 NONAME ; unsigned int TBTPinCodeEntryNotifierParams::RecommendedPinCodeMinLength(void) const
